/**
 * @file 查找html中的静态文件并返回
 */

'use strict';

var
/**
 * @desc lodash工具包
 */
  _ = require('lodash'),

  path = require('path'),

  /**
   * @desc 匹配html中的script标签
   */
  jsReg = /[ \f\t\v]*<script\s+[^>]*?src="(?!https?:)([^"]+\.js)"[^>]*?>[\s\S]*?<\/script>[ \f\t\v]*/ig,

  jsTextReg = /[ \f\t\v]*<script\s+[^>]*?[^>]*?>([\s\S]*?)<\/script>[ \f\t\v]*/ig,

  jsScriptReg = /:\"(.*?\.js)\"/g,

  /**
   * @desc 匹配html中的link标签
   */
  cssReg = /[ \f\t\v]*<link\s+[^>]*?href="(?!https?:)([^"]+\.css)"[^>]*?>[ \f\t\v]*/ig;

/**
 * @desc 查出字符串中的js和css标签
 * @param str
 * @returns {{js: Array, css: Array}}
 */
module.exports = function(str, opts) {
  var jsFiles = [],
    cssFile = [];
  str.replace(cssReg, function(all, value) {
      cssFile.push({
        str: _.trim(all),
        rel: path.join(opts.relativePath, value),
        ori: _.trim(value)
      });
    })
    .replace(jsReg, function(all, value) {

      if( value ) {
        jsFiles.push({
          str: _.trim(all),
          rel: path.join(opts.relativePath, value),
          ori: _.trim(value)
        });
      }
    })
    .replace(jsTextReg, function(all, value) {

      if(value) {
        value.replace( jsScriptReg, function(allStr, val) {
          jsFiles.push({
            str: _.trim(allStr),
            rel: path.join(opts.relativePath, val),
            ori: _.trim(val)
          })
        })
      }

    })
  return {
    js: jsFiles,
    css: cssFile
  };
}